@@ -3,10 +3,13 @@ import json
 
 import click
 from mmf_meta.core import scan, get_signature
+import sys
+import os
 
 
 @click.group()
 def cli():
+    sys.path.append(os.getcwd())
     return
 
 
